---8<--- "README.md:description"

## Where to next?

If you want to use the tool to create components,
we recommend going to our how-to guides to get started.
Some other potential points of interest:

- Getting Started instructions: [Getting Started][getting-started]
- The full API docs: [API reference](api/rscm/)
